@@ -21,7 +21,7 @@
  */
 
 /*
-   Copyright (C) 1997-2022 by Erik Nolf
+   Copyright (C) 1997-2023 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -1062,12 +1062,16 @@ int MdcConvertToTPCEcat7image(FILEINFO* fi,
   h->decay_corr_fctr = 0.0f;
   /* int <- ??? */
   h->processing_code = 0;
-  if (fi->gdata) {
+  if (fi->gatednr > 0 && fi->gdata != NULL) {
     /* int <- float (ms) */
-    h->gate_duration = fi->gdata->image_duration;
+    h->gate_duration = fi->gdata[0].image_duration;
     /* int <- float (ms) */
-    h->r_wave_offset = fi->gdata->window_low;
-    h->num_accepted_beats = fi->gdata->cycles_acquired;
+    h->r_wave_offset = fi->gdata[0].window_low;
+    h->num_accepted_beats = fi->gdata[0].cycles_acquired;
+  }else{
+    h->gate_duration = 0;
+    h->r_wave_offset = 0;
+    h->num_accepted_beats = 0;
   }
   /* float <- ??? */
   h->filter_cutoff_frequency = 0.0f;
