@@ -64,7 +64,7 @@
  */
 
 /*
-   Copyright (C) 1997-2022 by Erik Nolf
+   Copyright (C) 1997-2023 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -233,13 +233,13 @@ int MdcPrintValue(FILE *fp, Uint8 *pvalue, Uint16 type)
    case BIT64_S:
     {
       Int64 *val = (Int64 *) pvalue;
-      fprintf(fp,"%ld",val[0]);
+      fprintf(fp,"%lld",val[0]);
     }
     break;
    case BIT64_U:
     {
       Uint64 *val = (Uint64 *) pvalue;
-      fprintf(fp,"%lu",val[0]);
+      fprintf(fp,"%llu",val[0]);
     }
     break;
    case FLT32:
