@@ -33,7 +33,7 @@
  */
 
 /*
-   Copyright (C) 1997-2022 by Erik Nolf
+   Copyright (C) 1997-2023 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -300,8 +300,6 @@ GtkWidget *XMdcFileSelSaveCreateFormatMenu(GtkWidget *fs, guint format)
 
     if (LOOK) XMdcDisplayFatalErr(MDC_BAD_CODE,"Unexpected format to save");
 
-    XMdcFileSelSaveSetDefaultName(fs);
-
     gtk_combo_box_set_active(GTK_COMBO_BOX(formatmenu), selected);
     g_signal_connect(formatmenu, "changed"
 		               , G_CALLBACK(XMdcFileSelSaveCallbackFormatMenu)
@@ -457,6 +455,8 @@ void XMdcFileSelSave(GtkWidget *widget, guint format)
   if (MDC_ALIAS_NAME == MDC_YES) gtk_widget_hide(default_name);
   else gtk_widget_show(default_name);
 
+  XMdcFileSelSaveSetDefaultName(sfilew);
+
   response = gtk_dialog_run(GTK_DIALOG(sfilew));
 
   gtk_widget_hide(sfilew);
