@@ -12,9 +12,9 @@
  *                XMdcRawReadInteractive()        - Interactive raw read   *
  *                XMdcRawReadPredef()             - Read predefined raw    *
  *                XMdcRawReadCancel()             - Raw read break up      *
+ *                XMdcRawReadCallbackCancel()     - General Cancel callback*
  *                XMdcGetImageInfoPixelType()     - Get specified pixeltype*
  *                XMdcGetImageInfoCallbackApply() - Img Info Apply callback*
- *                XMdcGetImageInfoCallbackCancel()- Img Info Cancel        *
  *                XMdcGetImageInfo()              - Ask Img Info           *
  *                XMdcGetHeaderInfoCallbackApply()- Hdr Info Cont callback *
  *                XMdcGetHeaderInfo()             - Ask Hdr Info           *
@@ -24,7 +24,7 @@
  */
 
 /*
-   Copyright (C) 1997-2022 by Erik Nolf
+   Copyright (C) 1997-2023 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -219,6 +219,14 @@ void XMdcRawReadCancel(guint otype)
   MdcCleanUpFI(my.fi);
   if (otype == XMDC_RAW)
     gtk_widget_destroy(sRawReadSelection.HdrInfoWindow);
+
+  XMdcMainWidgetsResensitive();
+
+}
+
+void XMdcRawReadCallbackCancel(void)
+{
+  XMdcRawReadCancel(XMDC_RAW);
 }
 
 Int16 XMdcGetImageInfoPixelType(void)
@@ -324,11 +332,6 @@ void XMdcGetImageInfoCallbackApply(void)
 
 }
 
-void XMdcGetImageInfoCallbackCancel(void)
-{
-  XMdcRawReadCancel(XMDC_RAW);
-}
-
 void XMdcGetImageInfo(void)
 {
   GtkWidget *window=NULL;
@@ -588,7 +591,7 @@ void XMdcGetImageInfo(void)
   button = gtk_button_new_with_label("Cancel");
   gtk_box_pack_start(GTK_BOX(box2), button, TRUE, TRUE, 2);
   g_signal_connect(button, "clicked",
-                     G_CALLBACK(XMdcGetImageInfoCallbackCancel), NULL);
+                     G_CALLBACK(XMdcRawReadCallbackCancel), NULL);
   g_signal_connect_swapped(button, "clicked",
                      G_CALLBACK(gtk_widget_destroy),
                      window);
@@ -676,7 +679,7 @@ void XMdcGetHeaderInfo(void)
 
   window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
   g_signal_connect(window,"destroy",
-                     G_CALLBACK(XMdcWidgetCallbackDestroy),NULL);
+                     G_CALLBACK(gtk_widget_destroy),NULL);
   gtk_window_set_title(GTK_WINDOW(window),"Input Header Info");
   raw->HdrInfoWindow = window;
 
@@ -798,9 +801,8 @@ void XMdcGetHeaderInfo(void)
 
   button = gtk_button_new_with_label("Cancel");
   gtk_box_pack_start(GTK_BOX(box2),button,TRUE,TRUE,2);
-  g_signal_connect_swapped(button, "clicked",
-                    G_CALLBACK(gtk_widget_destroy),
-                    window);
+  g_signal_connect(button, "clicked",
+                    G_CALLBACK(XMdcRawReadCallbackCancel), NULL);
   gtk_widget_show(button);
 
   XMdcShowWidget(window);
